#!/usr/bin/env node
"use strict";

var _interopRequire = function (obj) { return obj && obj.__esModule ? obj["default"] : obj; };

var readFileSync = require("fs").readFileSync;

var joinPath = require("path").join;

var minimist = _interopRequire(require("minimist"));

var runAll = _interopRequire(require("./index"));

if (require.main === module) {
  main(process.argv.slice(2));
}

function printHelp() {
  console.log("\nUsage: npm-run-all [OPTIONS] [...tasks]\n\n  Run specified tasks.\n\n  Options:\n    -h, --help      Print this text.\n    -p, --parallel  Run specified tasks on parallel.\n                    By default, run on sequential.\n    -v, --version   Print version number.\n\n  See Also:\n    https://github.com/mysticatea/npm-run-all\n");
}

function printVersion() {
  var version = JSON.parse(readFileSync(joinPath(__dirname, "../package.json"), { encoding: "utf8" })).version;

  console.log("v" + version);
}

/*eslint no-process-exit:0*/
function main(args) {
  var options = minimist(args, {
    boolean: ["help", "parallel", "version"],
    alias: { h: "help", p: "parallel", v: "version" },
    unknown: function (arg) {
      if (arg[0] === "-") {
        console.error("Unknown Option: " + arg);
        process.exit(1);
      }
    }
  });

  if (options._.length === 0 || options.help) {
    printHelp();
    process.exit(0);
  }
  if (options.version) {
    printVersion();
    process.exit(0);
  }

  runAll(options._, {
    stdout: process.stdout,
    stderr: process.stderr,
    parallel: options.parallel
  })["catch"](function () {
    return process.exit(1);
  });
}